Re: [Slackbuilds-users] libquicktime

2016-09-17 Thread King Beowulf
On 09/17/2016 12:33 AM, Klaatu wrote:
> I've only been partly following this thread, but I have compiled
> libquicktime with ffmpeg 3.1.1 on my multilib system. Patch attached.
> Maybe it will help someone.
> 
> I have no memory of where I obtained this patch...maybe borrowed from Arch.
> 
> -klaatu
> 
> 
> 
> 
> On 17/09/16 19:10, Willy Sudiarto Raharjo wrote:
>>> Heinz can we modifiy the slackbuild for libquicktime?
>>>
>>> Fellype:
>>>This is how you fix libquicktime:
>>> linuxquestions   .
>>> org/questions/slackware-14/unable-to-install-libquicktime-on-slackware64-14-1-a-4175534366/
>>
>> https://slackbuilds.org/faq/#multilib
>>
>>
>>

libquicktime's CVS repo on Sourceforge has the patch from about 9 month
ago.
http://libquicktime.cvs.sourceforge.net/viewvc/libquicktime/libquicktime/plugins/ffmpeg/video.c?view=log=1.131=HEAD

Also Arch has both for ffmpeg2 and ffmpeg3.
https://git.archlinux.org/svntogit/community.git/tree/trunk?h=packages/libquicktime

So might be time to update the script on SBo (again).

-Ed




signature.asc
Description: OpenPGP digital signature
___
SlackBuilds-users mailing list
SlackBuilds-users@slackbuilds.org
http://lists.slackbuilds.org/mailman/listinfo/slackbuilds-users
Archives - https://lists.slackbuilds.org/pipermail/slackbuilds-users/
FAQ - https://slackbuilds.org/faq/



Re: [Slackbuilds-users] libquicktime

2016-09-17 Thread Klaatu
I've only been partly following this thread, but I have compiled
libquicktime with ffmpeg 3.1.1 on my multilib system. Patch attached.
Maybe it will help someone.

I have no memory of where I obtained this patch...maybe borrowed from Arch.

-klaatu




On 17/09/16 19:10, Willy Sudiarto Raharjo wrote:
>> Heinz can we modifiy the slackbuild for libquicktime?
>>
>> Fellype:
>>This is how you fix libquicktime:
>> linuxquestions   .
>> org/questions/slackware-14/unable-to-install-libquicktime-on-slackware64-14-1-a-4175534366/
> 
> https://slackbuilds.org/faq/#multilib
> 
> 
> 
> 
> ___
> SlackBuilds-users mailing list
> SlackBuilds-users@slackbuilds.org
> http://lists.slackbuilds.org/mailman/listinfo/slackbuilds-users
> Archives - https://lists.slackbuilds.org/pipermail/slackbuilds-users/
> FAQ - https://slackbuilds.org/faq/
> 

Index: libquicktime-1.2.4/plugins/ffmpeg/video.c
===
--- libquicktime-1.2.4.orig/plugins/ffmpeg/video.c
+++ libquicktime-1.2.4/plugins/ffmpeg/video.c
@@ -37,10 +37,10 @@
 #endif
 
 
-#ifdef  PIX_FMT_YUV422P10
-#define PIX_FMT_YUV422P10_OR_DUMMY PIX_FMT_YUV422P10
+#ifdef  AV_PIX_FMT_YUV422P10
+#define AV_PIX_FMT_YUV422P10_OR_DUMMY AV_PIX_FMT_YUV422P10
 #else
-#define PIX_FMT_YUV422P10_OR_DUMMY -1234
+#define AV_PIX_FMT_YUV422P10_OR_DUMMY -1234
 #endif
 
 #if LIBAVCODEC_VERSION_INT >= ((54<<16)|(1<<8)|0)
@@ -90,9 +90,9 @@ typedef struct
   int imx_bitrate;
   int imx_strip_vbi;
 
-  /* In some cases FFMpeg would report something like PIX_FMT_YUV422P, while
- we would like to treat it as PIX_FMT_YUVJ422P. It's only used for decoding */
-  enum PixelFormat reinterpret_pix_fmt;
+  /* In some cases FFMpeg would report something like AV_PIX_FMT_YUV422P, while
+ we would like to treat it as AV_PIX_FMT_YUVJ422P. It's only used for decoding */
+  enum AVPixelFormat reinterpret_pix_fmt;
   
   int is_imx;
   int y_offset;
@@ -137,42 +137,42 @@ typedef struct
 
 static const struct
   {
-  enum PixelFormat ffmpeg_id;
+  enum AVPixelFormat ffmpeg_id;
   int  lqt_id;
   int  exact;
   }
 colormodels[] =
   {
-{ PIX_FMT_YUV420P,   BC_YUV420P,   1 }, ///< Planar YUV 4:2:0 (1 Cr & Cb sample per 2x2 Y samples)
+{ AV_PIX_FMT_YUV420P,   BC_YUV420P,   1 }, ///< Planar YUV 4:2:0 (1 Cr & Cb sample per 2x2 Y samples)
 #if LIBAVUTIL_VERSION_INT < (50<<16)
-{ PIX_FMT_YUV422,BC_YUV422,1 },
+{ AV_PIX_FMT_YUV422,BC_YUV422,1 },
 #else
-{ PIX_FMT_YUYV422,   BC_YUV422,1 },
+{ AV_PIX_FMT_YUYV422,   BC_YUV422,1 },
 #endif
-{ PIX_FMT_RGB24, BC_RGB888,1 }, ///< Packed pixel, 3 bytes per pixel, RGBRGB...
-{ PIX_FMT_BGR24, BC_BGR888,1 }, ///< Packed pixel, 3 bytes per pixel, BGRBGR...
-{ PIX_FMT_YUV422P,   BC_YUV422P,   1 }, ///< Planar YUV 4:2:2 (1 Cr & Cb sample per 2x1 Y samples)
-{ PIX_FMT_YUV444P,   BC_YUV444P,   1 }, ///< Planar YUV 4:4:4 (1 Cr & Cb sample per 1x1 Y samples)
-{ PIX_FMT_YUV411P,   BC_YUV411P,   1 }, ///< Planar YUV 4:1:1 (1 Cr & Cb sample per 4x1 Y samples)
-{ PIX_FMT_YUV422P16, BC_YUV422P16, 1 }, ///< Planar 16 bit YUV 4:2:2 (1 Cr & Cb sample per 2x1 Y samples)
-#ifdef PIX_FMT_YUV422P10
-{ PIX_FMT_YUV422P10, BC_YUV422P10, 1 }, ///< 10 bit samples in uint16_t containers, planar 4:2:2
-#endif
-{ PIX_FMT_RGB565,BC_RGB565,1 }, ///< always stored in cpu endianness
-{ PIX_FMT_YUVJ420P,  BC_YUVJ420P,  1 }, ///< Planar YUV 4:2:0 full scale (jpeg)
-{ PIX_FMT_YUVJ422P,  BC_YUVJ422P,  1 }, ///< Planar YUV 4:2:2 full scale (jpeg)
-{ PIX_FMT_YUVJ444P,  BC_YUVJ444P,  1 }, ///< Planar YUV 4:4:4 full scale (jpeg)
+{ AV_PIX_FMT_RGB24, BC_RGB888,1 }, ///< Packed pixel, 3 bytes per pixel, RGBRGB...
+{ AV_PIX_FMT_BGR24, BC_BGR888,1 }, ///< Packed pixel, 3 bytes per pixel, BGRBGR...
+{ AV_PIX_FMT_YUV422P,   BC_YUV422P,   1 }, ///< Planar YUV 4:2:2 (1 Cr & Cb sample per 2x1 Y samples)
+{ AV_PIX_FMT_YUV444P,   BC_YUV444P,   1 }, ///< Planar YUV 4:4:4 (1 Cr & Cb sample per 1x1 Y samples)
+{ AV_PIX_FMT_YUV411P,   BC_YUV411P,   1 }, ///< Planar YUV 4:1:1 (1 Cr & Cb sample per 4x1 Y samples)
+{ AV_PIX_FMT_YUV422P16, BC_YUV422P16, 1 }, ///< Planar 16 bit YUV 4:2:2 (1 Cr & Cb sample per 2x1 Y samples)
+#ifdef AV_PIX_FMT_YUV422P10
+{ AV_PIX_FMT_YUV422P10, BC_YUV422P10, 1 }, ///< 10 bit samples in uint16_t containers, planar 4:2:2
+#endif
+{ AV_PIX_FMT_RGB565,BC_RGB565,1 }, ///< always stored in cpu endianness
+{ AV_PIX_FMT_YUVJ420P,  BC_YUVJ420P,  1 }, ///< Planar YUV 4:2:0 full scale (jpeg)
+{ AV_PIX_FMT_YUVJ422P,  BC_YUVJ422P,  1 }, ///< Planar YUV 4:2:2 full scale (jpeg)
+{ AV_PIX_FMT_YUVJ444P,  BC_YUVJ444P,  1 }, ///< Planar YUV 4:4:4 full scale (jpeg)
 #if LIBAVUTIL_VERSION_INT < (50<<16)
-{ PIX_FMT_RGBA32,BC_RGBA,  0 }, ///< Packed pixel, 4 bytes per pixel, BGRABGRA...
+{ 

Re: [Slackbuilds-users] libquicktime

2016-09-17 Thread Willy Sudiarto Raharjo
> I believe a note should be added to the package readme what do you guys
> think?

It's already mentioned in FAQ


-- 
Willy Sudiarto Raharjo



signature.asc
Description: OpenPGP digital signature
___
SlackBuilds-users mailing list
SlackBuilds-users@slackbuilds.org
http://lists.slackbuilds.org/mailman/listinfo/slackbuilds-users
Archives - https://lists.slackbuilds.org/pipermail/slackbuilds-users/
FAQ - https://slackbuilds.org/faq/



Re: [Slackbuilds-users] libquicktime

2016-09-17 Thread Fernando Lopez
I believe a note should be added to the package readme what do you guys
think?

On Sat, Sep 17, 2016 at 1:10 AM, Willy Sudiarto Raharjo <
will...@slackbuilds.org> wrote:

> > Heinz can we modifiy the slackbuild for libquicktime?
> >
> > Fellype:
> >This is how you fix libquicktime:
> > linuxquestions   .
> > org/questions/slackware-14/unable-to-install-
> libquicktime-on-slackware64-14-1-a-4175534366/
>
> https://slackbuilds.org/faq/#multilib
>
>
> --
> Willy Sudiarto Raharjo
>
>
> ___
> SlackBuilds-users mailing list
> SlackBuilds-users@slackbuilds.org
> http://lists.slackbuilds.org/mailman/listinfo/slackbuilds-users
> Archives - https://lists.slackbuilds.org/pipermail/slackbuilds-users/
> FAQ - https://slackbuilds.org/faq/
>
>
>


-- 


Regards,
Fernando Lopez Jr.
___
SlackBuilds-users mailing list
SlackBuilds-users@slackbuilds.org
http://lists.slackbuilds.org/mailman/listinfo/slackbuilds-users
Archives - https://lists.slackbuilds.org/pipermail/slackbuilds-users/
FAQ - https://slackbuilds.org/faq/



Re: [Slackbuilds-users] libquicktime

2016-09-17 Thread Willy Sudiarto Raharjo
> Heinz can we modifiy the slackbuild for libquicktime?
> 
> Fellype:
>This is how you fix libquicktime:
> linuxquestions   .
> org/questions/slackware-14/unable-to-install-libquicktime-on-slackware64-14-1-a-4175534366/

https://slackbuilds.org/faq/#multilib


-- 
Willy Sudiarto Raharjo



signature.asc
Description: OpenPGP digital signature
___
SlackBuilds-users mailing list
SlackBuilds-users@slackbuilds.org
http://lists.slackbuilds.org/mailman/listinfo/slackbuilds-users
Archives - https://lists.slackbuilds.org/pipermail/slackbuilds-users/
FAQ - https://slackbuilds.org/faq/



Re: [Slackbuilds-users] libquicktime vs. ffmpeg-2.1

2013-11-06 Thread Heinz Wiesinger
On Wednesday 06 November 2013 08:58:30 Niki Kovacs wrote:
 Hi,
 
 I just built libquicktime on -current. I have ffmpeg-2.1 installed, and
 the build fails with the stock sources.
 
 BLFS have a patch for that, which resolves the problem:
 
 http://www.linuxfromscratch.org/patches/blfs/svn/libquicktime-1.2.4-ffmpeg2- 
 1.patch

Hi Niki,

Thanks for the notice. We already have a fix for that in git master as well:

http://slackbuilds.org/cgit/slackbuilds/commit/?id=32c07cd361d45b114beb62455c0038f2f0789f4a

Grs,
Heinz

signature.asc
Description: This is a digitally signed message part.
___
SlackBuilds-users mailing list
SlackBuilds-users@slackbuilds.org
http://lists.slackbuilds.org/mailman/listinfo/slackbuilds-users
Archives - http://lists.slackbuilds.org/pipermail/slackbuilds-users/
FAQ - http://slackbuilds.org/faq/